@@ -11,6 +11,7 @@ public class AttachUserToVmFromPoolAndRunParameters extends VmPoolUserParameters
     private boolean internal;
 
     private boolean vmPrestarted;
+    private boolean nonPrestartedVmLocked;
 
     public AttachUserToVmFromPoolAndRunParameters() {
     }
@@ -36,4 +37,12 @@ public class AttachUserToVmFromPoolAndRunParameters extends VmPoolUserParameters
         this.vmPrestarted = vmPrestarted;
     }
 
+    public boolean isNonPrestartedVmLocked() {
+        return nonPrestartedVmLocked;
+    }
+
+    public void setNonPrestartedVmLocked(boolean nonPrestartedVmLocked) {
+        this.nonPrestartedVmLocked = nonPrestartedVmLocked;
+    }
+
 }
