@@ -8,5 +8,6 @@ public enum EventType {
     VDSSTOARGEPROBLEMS,
     DOMAINMONITORING,
     VDSCLEARCACHE,
-    VDSCONNECTTOPOOL;
+    VDSCONNECTTOPOOL,
+    POOLREFRESH;
 }
