@@ -1,11 +1,8 @@
 package org.ovirt.engine.ui.webadmin.section.main.view.popup.vm;
 
-import org.ovirt.engine.core.common.businessentities.Cluster;
 import org.ovirt.engine.core.common.businessentities.VDS;
 import org.ovirt.engine.ui.common.editor.UiCommonEditorDriver;
-import org.ovirt.engine.ui.common.idhandler.WithElementId;
 import org.ovirt.engine.ui.common.view.popup.AbstractModelBoundPopupView;
-import org.ovirt.engine.ui.common.widget.dialog.AdvancedParametersExpander;
 import org.ovirt.engine.ui.common.widget.dialog.SimpleDialogPanel;
 import org.ovirt.engine.ui.common.widget.editor.ListModelListBoxEditor;
 import org.ovirt.engine.ui.common.widget.editor.generic.EntityModelRadioButtonEditor;
@@ -18,12 +15,12 @@ import org.ovirt.engine.ui.webadmin.ApplicationConstants;
 import org.ovirt.engine.ui.webadmin.ApplicationMessages;
 import org.ovirt.engine.ui.webadmin.gin.AssetProvider;
 import org.ovirt.engine.ui.webadmin.section.main.presenter.popup.vm.VmMigratePopupPresenterWidget;
+
 import com.google.gwt.core.client.GWT;
 import com.google.gwt.event.shared.EventBus;
 import com.google.gwt.uibinder.client.UiBinder;
 import com.google.gwt.uibinder.client.UiField;
 import com.google.gwt.user.client.ui.Label;
-import com.google.gwt.user.client.ui.Panel;
 import com.google.inject.Inject;
 
 public class VmMigratePopupView extends AbstractModelBoundPopupView<MigrateModel>
@@ -60,19 +57,6 @@ public class VmMigratePopupView extends AbstractModelBoundPopupView<MigrateModel
     @Ignore
     Label message3;
 
-    @UiField
-    @Ignore
-    AdvancedParametersExpander advancedOptionsExpander;
-
-    @UiField
-    @Ignore
-    Panel advancedOptionsExpanderContent;
-
-    @UiField(provided = true)
-    @Path(value = "clusters.selectedItem")
-    @WithElementId("clusters")
-    public ListModelListBoxEditor<Cluster> clustersEditor;
-
     private final Driver driver = GWT.create(Driver.class);
 
     private static final ApplicationConstants constants = AssetProvider.getConstants();
@@ -84,8 +68,6 @@ public class VmMigratePopupView extends AbstractModelBoundPopupView<MigrateModel
         initEditors();
         initWidget(ViewUiBinder.uiBinder.createAndBindUi(this));
 
-        advancedOptionsExpander.initWithContent(advancedOptionsExpanderContent.getElement());
-
         localize();
         driver.initialize(this);
     }
@@ -95,15 +77,12 @@ public class VmMigratePopupView extends AbstractModelBoundPopupView<MigrateModel
         selectDestinationHostEditor = new EntityModelRadioButtonEditor("1"); //$NON-NLS-1$
 
         hostsListEditor = new ListModelListBoxEditor<>(new NameRenderer<VDS>());
-
-        clustersEditor = new ListModelListBoxEditor<>(new NameRenderer<Cluster>());
     }
 
     void localize() {
         selectHostAutomaticallyEditor.setLabel(constants.vmMigratePopupSelectHostAutomaticallyLabel());
         selectDestinationHostEditor.setLabel(constants.vmMigratePopupSelectDestinationHostLabel());
         hostsListEditor.setLabel(constants.vmMigratePopupHostsListLabel());
-        clustersEditor.setLabel(constants.hostClusterVmPopup());
         message1.setText(messages.migrateHostDisabledVMsInServerClusters());
         message2.setText(messages.migrateSomeVmsAlreadyRunningOnHost());
         message3.setText(messages.migrateNoAvailableHost());
