@@ -1,18 +1,29 @@
 package org.ovirt.engine.ui.webadmin.section.main.view.tab.quota;
 
+import org.ovirt.engine.ui.common.idhandler.ElementIdHandler;
 import org.ovirt.engine.ui.common.widget.tab.AbstractTabPanel;
 import org.ovirt.engine.ui.webadmin.section.main.presenter.tab.quota.QuotaSubTabPanelPresenter;
 import org.ovirt.engine.ui.webadmin.section.main.view.AbstractSubTabPanelView;
 import org.ovirt.engine.ui.webadmin.widget.tab.SimpleTabPanel;
+import com.google.gwt.core.client.GWT;
 
 public class QuotaSubTabPanelView extends AbstractSubTabPanelView implements QuotaSubTabPanelPresenter.ViewDef {
 
+    interface ViewIdHandler extends ElementIdHandler<QuotaSubTabPanelView> {
+        ViewIdHandler idHandler = GWT.create(ViewIdHandler.class);
+    }
+
     private final SimpleTabPanel tabPanel = new SimpleTabPanel();
 
     public QuotaSubTabPanelView() {
         initWidget(getTabPanel());
     }
 
+    @Override
+    protected void generateIds() {
+        ViewIdHandler.idHandler.generateAndSetIds(this);
+    }
+
     @Override
     protected Object getContentSlot() {
         return QuotaSubTabPanelPresenter.TYPE_SetTabContent;
